bet.calculateP package
======================

Submodules
----------

bet.calculateP.calculateError module
------------------------------------

.. automodule:: bet.calculateP.calculateError
    :members:
    :undoc-members:
    :show-inheritance:

bet.calculateP.calculateP module
--------------------------------

.. automodule:: bet.calculateP.calculateP
    :members:
    :undoc-members:
    :show-inheritance:

bet.calculateP.calculateR module
------------------------------------

.. automodule:: bet.calculateP.calculateR
    :members:
    :undoc-members:
    :show-inheritance:

bet.calculateP.simpleFunP module
--------------------------------

.. automodule:: bet.calculateP.simpleFunP
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: bet.calculateP
    :members:
    :undoc-members:
    :show-inheritance:
